==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/BehaviorPreferences/ts/BehaviorPreferences_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>BehaviorPreferences</name>
    <message>
        <location filename="../BehaviorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Vue graphique</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Behavior</source>
        <translation>Comportement</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+48"/>
        <source>Double-Click</source>
        <translation>Double-clic</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Double-click to edit text</source>
        <translation>Double-cliquez pour modifier texte</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click to edit hatch</source>
        <translation>Double-cliquez pour modifier hachure</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click on block reference opens block</source>
        <translation>Double-cliquez sur une référence de bloc pour ouvrir le bloc</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Right double-click to reset</source>
        <translation>Droit double-cliquez sur pour réinitialiser</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Blocks</source>
        <translation>Blocs</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Select block references together with attributes</source>
        <translation>Sélectionner références de bloc ainsi que leurs attributs</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Hide attributes when block references are hidden</source>
        <translation>Masquer les attributs lorsque les références de blocs sont cachés</translation>
    </message>
    <message>
        <location line="-85"/>
        <source>Right-Click</source>
        <translation>Clic-droit</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Right-click to deselect entities</source>
        <translation>Clic-droit pour désélectionner des entités</translation>
    </message>
    <message>
        <source>Right-click on entity shows context menu</source>
        <translation type="vanished">Clic-droit sur entité montre menu contextuel</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Double-click to select contour</source>
        <translation>Double-cliquez pour sélectionner contour</translation>
    </message>
    <message>
        <source>Block Selection</source>
        <translation type="vanished">Bloc sélection</translation>
    </message>
    <message>
        <source>Select block reference with attribute</source>
        <translation type="obsolete">Choisir référence de bloc avec l&apos;attribut</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Cursor Range</source>
        <translation>Gamme de curseur de souris</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Cursor range for snap:</source>
        <translation>Gamme de curseur de souris pour accrochage :</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Cursor range for picking entities:</source>
        <translation>Gamme de curseur pour capter des entités :</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/BehaviorPreferences/ts/BehaviorPreferences_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>BehaviorPreferences</name>
    <message>
        <location filename="../BehaviorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Vue graphique</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Behavior</source>
        <translation>Comportement</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+48"/>
        <source>Double-Click</source>
        <translation>Double-clic</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Double-click to edit text</source>
        <translation>Double-cliquez pour modifier texte</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click to edit hatch</source>
        <translation>Double-cliquez pour modifier hachure</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click on block reference opens block</source>
        <translation>Double-cliquez sur une référence de bloc pour ouvrir le bloc</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Right double-click to reset</source>
        <translation>Droit double-cliquez sur pour réinitialiser</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Blocks</source>
        <translation>Blocs</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Select block references together with attributes</source>
        <translation>Sélectionner références de bloc ainsi que leurs attributs</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Hide attributes when block references are hidden</source>
        <translation>Masquer les attributs lorsque les références de blocs sont cachés</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Highlight entity within range</source>
        <translation>Mettre en surbrillance l&apos;entité dans la plage</translation>
    </message>
    <message>
        <source>Keyboard Operations</source>
        <translation type="vanished">Opérations de clavier</translation>
    </message>
    <message>
        <source>Angle step for rotating:</source>
        <translation type="vanished">Etape d&apos;angle pour la rotation :</translation>
    </message>
    <message>
        <location line="-211"/>
        <source>Right-Click</source>
        <translation>Clic-droit</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Right-click to deselect entities</source>
        <translation>Clic-droit pour désélectionner des entités</translation>
    </message>
    <message>
        <source>Right-click on entity shows context menu</source>
        <translation type="vanished">Clic-droit sur entité montre menu contextuel</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Double-click to select contour</source>
        <translation>Double-cliquez pour sélectionner contour</translation>
    </message>
    <message>
        <source>Block Selection</source>
        <translation type="vanished">Bloc sélection</translation>
    </message>
    <message>
        <source>Select block reference with attribute</source>
        <translation type="obsolete">Choisir référence de bloc avec l&apos;attribut</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Cursor Range</source>
        <translation>Gamme de curseur de souris</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Cursor range for snap:</source>
        <translation>Gamme de curseur de souris pour accrochage :</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Cursor range for picking entities:</source>
        <translation>Gamme de curseur pour capter des entités :</translation>
    </message>
</context>
</TS>
